@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -18,11 +18,9 @@
      misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
 */
-#include "../../SDL_internal.h"
+#include "SDL_internal.h"
 
-#include "SDL_androidvideo.h"
-
-extern void Android_PumpEvents_Blocking(_THIS);
-extern void Android_PumpEvents_NonBlocking(_THIS);
-
-/* vi: set ts=4 sw=4 expandtab: */
+extern void Android_InitEvents(void);
+extern void Android_PumpEvents(Sint64 timeoutNS);
+extern bool Android_WaitActiveAndLockActivity(void);
+extern void Android_QuitEvents(void);
